summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGuenter Bartsch <guenter@users.sourceforge.net>2003-02-16 19:55:16 +0000
committerGuenter Bartsch <guenter@users.sourceforge.net>2003-02-16 19:55:16 +0000
commit9ec2a3efc4bb12cf92abbf2fe852aaf5ae35d748 (patch)
tree19151d8fb3fc9e4578d4fa782cb2252116bec835
parent2efdb2283a7defdd2e496cd14ee2b8c83a0d7c62 (diff)
downloadxine-lib-9ec2a3efc4bb12cf92abbf2fe852aaf5ae35d748.tar.gz
xine-lib-9ec2a3efc4bb12cf92abbf2fe852aaf5ae35d748.tar.bz2
bigger buffers for smoother playback
CVS patchset: 4174 CVS date: 2003/02/16 19:55:16
-rw-r--r--src/xine-engine/video_decoder.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/xine-engine/video_decoder.c b/src/xine-engine/video_decoder.c
index d99c55832..29cf8a7e3 100644
--- a/src/xine-engine/video_decoder.c
+++ b/src/xine-engine/video_decoder.c
@@ -17,7 +17,7 @@
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
*
- * $Id: video_decoder.c,v 1.125 2003/02/01 19:22:30 guenter Exp $
+ * $Id: video_decoder.c,v 1.126 2003/02/16 19:55:16 guenter Exp $
*
*/
@@ -367,13 +367,13 @@ void video_decoder_init (xine_stream_t *stream) {
int err;
/* The fifo size is based on dvd playback where buffers are filled
* with 2k of data. With 500 buffers and a typical video data rate
* of 4 Mbit/s, the fifo can hold about 2 seconds of video, wich
* should be enough to compensate for drive delays.
* We provide buffers of 8k size instead of 2k for demuxers sending
* larger chunks.
*/
- stream->video_fifo = fifo_buffer_new (500, 8192);
+ stream->video_fifo = fifo_buffer_new (1000, 8192);
stream->spu_track_map_entries = 0;
pthread_attr_init(&pth_attrs);
@@ -367,13 +367,13 @@ void video_decoder_init (xine_stream_t *stream) {
int err;
/* The fifo size is based on dvd playback where buffers are filled
- * with 2k of data. With 500 buffers and a typical video data rate
- * of 4 Mbit/s, the fifo can hold about 2 seconds of video, wich
+ * with 2k of data. With 1000 buffers and a typical video data rate
+ * of 8 Mbit/s, the fifo can hold about 2 seconds of video, wich
* should be enough to compensate for drive delays.
* We provide buffers of 8k size instead of 2k for demuxers sending